import network
import socket
from machine import Pin
import time

# Wi-Fi credentials
SSID = "YourSSID"  # Replace with your Wi-Fi name
PASSWORD = "YourPassword"  # Replace with your Wi-Fi password

# Connect to Wi-Fi
def connect_to_wifi():
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(SSID, PASSWORD)
    
    while not wlan.isconnected():
        print("Connecting to Wi-Fi...")
        time.sleep(1)
    
    print("Connected to Wi-Fi")
    print("IP Address:", wlan.ifconfig()[0])
    return wlan

connect_to_wifi()

# Set up the LED
led = Pin(25, Pin.OUT)  # GP25 controls the built-in LED
led.value(0)  # Start with LED off

# Web server to control the LED
def start_server():
    addr = socket.getaddrinfo('0.0.0.0', 80)[0][-1]
    s = socket.socket()
    s.bind(addr)
    s.listen(1)
    print("Listening on", addr)

    while True:
        cl, addr = s.accept()
        print("Client connected from", addr)
        request = cl.recv(1024).decode()
        print("Request:", request)

        # Control the LED based on the request
        if "/led/on" in request:
            led.value(1)  # Turn LED on
            response = "LED is ON"
        elif "/led/off" in request:
            led.value(0)  # Turn LED off
            response = "LED is OFF"
        elif "/led/flash" in request:
            response = "LED is FLASHING"
            for _ in range(5):  # Flash LED 5 times
                led.value(1)
                time.sleep(0.5)
                led.value(0)
                time.sleep(0.5)
        else:
            response = "Welcome! Use /led/on, /led/off, or /led/flash."

        # Create a simple HTML page
        html = f"""<!DOCTYPE html>
        <html>
        <head><title>Pico W LED Control</title></head>
        <body>
        <h1>{response}</h1>
        <p><a href="/led/on">Turn LED ON</a></p>
        <p><a href="/led/off">Turn LED OFF</a></p>
        <p><a href="/led/flash">Flash LED</a></p>
        </body>
        </html>
        """
        cl.send("HTTP/1.0 200 OK\r\nContent-type: text/html\r\n\r\n")
        cl.send(html)
        cl.close()

start_server()
